Return a table that for all available flags returns the country name,
the continent, the flag code and the capital. The flag code must be used
as input in functions like flag_icon() and run_taxonomy().
Return a table that for all available flags returns the country name,
the continent, the flag code and the capital. The flag code must be used
as input in functions like flag_icon() and run_taxonomy().